@@ -1,8 +1,9 @@
 import inspect
+import os
 import pathlib
 from functools import lru_cache
 from io import TextIOBase
-from typing import Sequence, Union, TypeVar, Optional, Literal, Iterable
+from typing import Sequence, Union, TypeVar, Optional, Literal, Iterable, Dict, Tuple
 
 import polars as pl
 from black import Mode, format_str
@@ -148,7 +149,7 @@ class ExprTool:
 
         return exprs_list
 
-    def cse(self, exprs, symbols_repl=None, exprs_src=None):
+    def cse(self, exprs, symbols_repl=None, exprs_src=None, skip_simplify=False):
         """多个子公式+长公式，提取公共公式
 
         Parameters
@@ -175,7 +176,11 @@ class ExprTool:
         _exprs = [k for k, v in exprs]
 
         # 注意：对于表达式右边相同，左边不同的情况，会当成一个处理
-        repl, redu = cse(_exprs, symbols_repl, optimizations=[(cse_opts.sub_pre, cse_opts.sub_post), ])
+        if skip_simplify:
+            repl, redu = cse(_exprs, symbols_repl, optimizations=[])
+        else:
+            repl, redu = cse(_exprs, symbols_repl, optimizations=[(cse_opts.sub_pre, cse_opts.sub_post), ])
+
         outputs_len = len(exprs_src)
 
         new_redu = []
@@ -193,15 +198,14 @@ class ExprTool:
 
         return self.exprs_list
 
-    def dag(self, merge: bool, skip_columns, date, asset):
+    def dag(self, merge: bool, skip_columns, date, asset, skip_simplify):
         """生成DAG"""
         G = dag_start(self.exprs_list, self.get_current_func, self.get_current_func_kwargs, date, asset)
         if merge:
-            G = dag_middle(G, self.exprs_names, skip_columns, self.get_current_func, self.get_current_func_kwargs, date,
-                           asset)
+            G = dag_middle(G, self.exprs_names, skip_columns, self.get_current_func, self.get_current_func_kwargs, date, asset, skip_simplify)
         return dag_end(G)
 
-    def all(self, exprs_src, style: Literal['pandas', 'polars', 'sql'] = 'polars',
+    def all(self, exprs_src, style: Literal['pandas', 'polars', 'sql', 'rust'] = 'polars',
             template_file: Optional[str] = None,
             replace: bool = True, regroup: bool = False, format: bool = True,
             date='date', asset='asset',
@@ -245,19 +249,19 @@ class ExprTool:
         代码字符串
 
         """
-        assert style in ('pandas', 'polars', 'sql')
+        assert style in ('pandas', 'polars', 'sql', 'rust')
 
         if replace:
             exprs_src = replace_exprs(exprs_src)
 
         # 子表达式在前，原表式在最后
-        exprs_dst, syms_dst = self.merge(date, asset, exprs_src, skip_simplify)
+        exprs_dst, syms_dst = self.merge(date, asset, exprs_src, skip_simplify=skip_simplify)
         syms_dst = list(set(syms_dst) - _RESERVED_WORD_)
 
         # 提取公共表达式
-        self.cse(exprs_dst, symbols_repl=numbered_symbols('_x_'), exprs_src=exprs_src)
+        self.cse(exprs_dst, symbols_repl=numbered_symbols('_x_'), exprs_src=exprs_src, skip_simplify=skip_simplify)
         # 有向无环图流转
-        exprs_ldl, G = self.dag(True, skip_columns, date, asset)
+        exprs_ldl, G = self.dag(True, skip_columns, date, asset, skip_simplify=skip_simplify)
 
         if regroup:
             exprs_ldl.optimize(merge=style != 'sql')
@@ -269,6 +273,9 @@ class ExprTool:
         elif style == 'sql':
             from expr_codegen.sql.code import codegen
             format = False
+        elif style == 'rust':
+            from expr_codegen.rust.code import codegen
+            format = False
         else:
             raise ValueError(f'unknown style {style}')
 
@@ -296,7 +303,7 @@ class ExprTool:
                   extra_codes: str,
                   output_file: str,
                   convert_xor: bool,
-                  style: Literal['pandas', 'polars', 'sql'] = 'polars',
+                  style: Literal['pandas', 'polars', 'sql', 'rust'] = 'polars',
                   template_file: Optional[str] = None,
                   date: str = 'date', asset: str = 'asset',
                   over_null: Literal['order_by', 'partition_by', None] = 'partition_by',
@@ -380,7 +387,7 @@ def codegen_exec(df: Union[DataFrame, None],
                  output_file: Union[str, TextIOBase, None] = None,
                  run_file: Union[bool, str] = False,
                  convert_xor: bool = False,
-                 style: Literal['pandas', 'polars', 'sql'] = 'polars',
+                 style: Literal['pandas', 'polars', 'sql', 'rust'] = 'polars',
                  template_file: Optional[str] = None,
                  date: str = 'date', asset: str = 'asset',
                  table_name: str = 'self',
@@ -388,7 +395,7 @@ def codegen_exec(df: Union[DataFrame, None],
                  skip_simplify: bool = False,
                  skip_columns: Iterable[str] = (),
                  **kwargs) -> Union[DataFrame, str]:
-    """快速转换源代码并执行
+    r"""快速转换源代码并执行
 
     Parameters
     ----------
@@ -398,7 +405,12 @@ def codegen_exec(df: Union[DataFrame, None],
     codes:
         函数体。此部分中的表达式会被翻译成目标代码
     extra_codes: str
-        额外代码。不做处理，会被直接复制到目标代码中
+        额外代码。不做处理，会被直接复制到目标代码中。例如：
+
+        r'CS_SW_L1 = r"^sw_l1_\d+$"'
+
+        apply_const_to_expr()
+
     output_file: str| TextIOBase
         保存生成的目标代码到文件中
     run_file: bool or str
@@ -407,6 +419,7 @@ def codegen_exec(df: Union[DataFrame, None],
         - 如果是字符串，会自动从run_file中读取代码
         - 如果是模块名，会自动从模块中读取代码(可调试)
             - 注意：可能调用到其他目录下的同名模块，所以保存的文件名要有辨识度
+        - 如果文件不存在，先生成文件。第二次从生成的文件中生成
     convert_xor: bool
         ^ 转成异或还是乘方
     style: str
@@ -433,6 +446,9 @@ def codegen_exec(df: Union[DataFrame, None],
         -2 表示最近两天 >=date[-2]
     skip_simplify:bool
         遗传算法时很有可能出现OPEN/OPEN，可以跳过化简步骤
+        1. 跳过cse前的simplify
+        2. 跳过cse时的optimizations
+        3. 跳过DAG中的部分merge步骤
     skip_columns:
         已经存在的列不参与计算。可用于加快计算速度。只在计算耗时久时再用，否则没有必要
         例如：在研发阶段，第一次计算100个因子，第二次，只改动了其中的5个，所以只要将这5个从df.columns中排除即可。
@@ -466,10 +482,12 @@ def codegen_exec(df: Union[DataFrame, None],
 
         if input_file is not None:
             if input_file.endswith('.py'):
-                return _get_func_from_file_py(input_file)(df, ge_date_idx)
+                if os.path.exists(input_file):
+                    return _get_func_from_file_py(input_file)(df, ge_date_idx)
             elif input_file.endswith('.sql'):
-                with pl.SQLContext(frames={table_name: df}) as ctx:
-                    return ctx.execute(_get_code_from_file(input_file), eager=isinstance(df, _pl_DataFrame))
+                if os.path.exists(input_file):
+                    with pl.SQLContext(frames={table_name: df}) as ctx:
+                        return ctx.execute(_get_code_from_file(input_file), eager=isinstance(df, _pl_DataFrame))
             else:
                 return _get_func_from_module(input_file)(df, ge_date_idx)  # 可断点调试
     else:
@@ -500,6 +518,8 @@ def codegen_exec(df: Union[DataFrame, None],
     if df is None:
         # 如果df为空，直接返回代码
         return code
+    elif style == 'rust':
+        return code
     elif style == 'sql':
         with pl.SQLContext(frames={table_name: df}) as ctx:
             return ctx.execute(code, eager=isinstance(df, _pl_DataFrame))
